#[non_exhaustive]pub enum Error {
NonOverlappingQuorums,
NoStrategyFound,
NoQuorumSystemFound,
InvalidDistribution(String),
LpError(String),
InvalidQuorumSystem(String),
InvalidExpression(String),
}Expand description
Errors that can occur when working with quorum systems
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NonOverlappingQuorums
Some write quorum does not intersect some read quorum.
NoStrategyFound
The constraints are infeasible, or there are no f-resilient
quorums for the requested f.
NoQuorumSystemFound
Search found no quorum system satisfying the requirements.
InvalidDistribution(String)
Invalid read/write distribution.
LpError(String)
The LP solver failed for a reason other than infeasibility.
InvalidQuorumSystem(String)
Invalid arguments to a quorum system or strategy operation.
InvalidExpression(String)
Invalid expression or geometry arguments.