max_of_segments

Function max_of_segments 

pub fn max_of_segments(segments: &[Segment]) -> Result<Vec<(f64, f64)>>
Compute the upper envelope of a set of compatible segments.

Returns a list of (x, y) pairs tracing the maximum of all segments. All segments must share the same x-range (typically [0, 1]).

Errors

Returns an error if the slice is empty or segments have different x-ranges.