pub struct Segment {
pub l: Point,
pub r: Point,
}Expand description
A line segment between two points where l.x < r.x.
Fields
l: PointLeft endpoint (smaller x).
r: PointRight endpoint (larger x).
Implementations
Sourceimpl Segment
impl Segment
Sourcepub fn new(l: Point, r: Point) -> Result<Self>
pub fn new(l: Point, r: Point) -> Result<Self>
Create a new segment from left point l to right point r.
Errors
Returns an error if l == r or l.x >= r.x.
Sourcepub fn approximately_equal(&self, other: &Self) -> bool
pub fn approximately_equal(&self, other: &Self) -> bool
Whether two segments are approximately equal (within relative tolerance 1e-5 on both y-coordinates).
Sourcepub fn compatible(&self, other: &Self) -> bool
pub fn compatible(&self, other: &Self) -> bool
Whether two segments share the same x-range.
Sourcepub fn above(&self, other: &Self) -> Result<bool>
pub fn above(&self, other: &Self) -> Result<bool>
Whether self is strictly above other (both endpoints at
least as high, and not equal).
Errors
Returns an error if the segments are not compatible.
Sourcepub fn above_eq(&self, other: &Self) -> Result<bool>
pub fn above_eq(&self, other: &Self) -> Result<bool>
Whether self is above or equal to other.
Errors
Returns an error if the segments are not compatible.
Sourcepub fn intersects(&self, other: &Self) -> Result<bool>
pub fn intersects(&self, other: &Self) -> Result<bool>
Whether two compatible segments intersect.
Errors
Returns an error if the segments are not compatible.