search

Function search 

pub fn search<T: Element>(
    nodes: &[Node<T>],
    config: &SearchConfig,
) -> Result<SearchResult<T>>
Search for the quorum system over nodes that best meets config.

Candidates of height ≤ 2 are tried first, then all heights, until the candidates run out or config.timeout passes.

Errors