pub enum Error {
NonOverlappingQuorums,
NoStrategyFound,
NoQuorumSystemFound,
InvalidDistribution(String),
LpError(String),
InvalidQuorumSystem(String),
InvalidExpression(String),
}Expand description
Errors that can occur when working with quorum systems
Variants
NonOverlappingQuorums
Read and write quorums do not overlap
NoStrategyFound
No strategy could be found satisfying the constraints
NoQuorumSystemFound
No quorum system could be found satisfying the requirements
InvalidDistribution(String)
Invalid distribution specification
LpError(String)
Linear programming solver error
InvalidQuorumSystem(String)
Invalid quorum system configuration
InvalidExpression(String)
Invalid expression