pub fn search<T: Element>(
nodes: &[Node<T>],
config: &SearchConfig,
) -> Result<SearchResult<T>>Expand description
Search for the quorum system over nodes that best meets config.
Candidates of height ≤ 2 are tried first, then all heights, until the
candidates run out or config.timeout passes.
Errors
Error::InvalidQuorumSystemifnodesis empty or a limit is set on the metric being optimized.Error::InvalidDistributionif the read/write fraction is invalid.Error::NoQuorumSystemFoundif no candidate meets the requirements before the timeout.